        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
}
