        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>1</strong> miembros: 24 <strong>control</strong><br>0,1,5,7,9,10,11,12,13,16,19,21,22,27,32,34,37,40,41,44,45,48,49,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 14 <br>3,15,17,18,23,24,29,30,31,33,42,43,46,47';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260623 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 13 <br>2,4,6,8,14,20,25,26,28,35,36,38,39';}
}
